@@ -1,7 +1,7 @@
 import enum
 import typing
 
-from PyQt5 import QtWidgets, QtCore, QtGui
+from qtpy import QtWidgets, QtGui
 
 from .categorylayoutwidget import RibbonCategoryLayoutWidget
 from .panel import RibbonPanel
@@ -39,9 +39,6 @@ class RibbonCategory(QtWidgets.QFrame):
     #: color of the context category
     _color: typing.Optional[QtGui.QColor]
 
-    #: The signal that is emitted when the display options button is clicked.
-    displayOptionsButtonClicked = QtCore.pyqtSignal(bool)
-
     @typing.overload
     def __init__(self, title: str = '', style: RibbonCategoryStyle = RibbonCategoryStyle.Normal,
                  color: QtGui.QColor = None, parent=None):
@@ -99,7 +96,7 @@ class RibbonCategory(QtWidgets.QFrame):
     def categoryStyle(self):
         """Return the button style of the category.
 
-        :return: The button tyle.
+        :return: The button style.
         """
         return self._style
 
